what.utils API documentation

# what.utils

Utility functions for WHAT.

## what.utils.logger.get_logger

## what.utils.resize.bilinear_resize

## what.utils.proj.proj_lp

View Source

     1r'''
     2Utility functions for WHAT.
     3
     4<br />
     5
     6## what.utils.logger.get_logger
     7## what.utils.resize.bilinear_resize
     8## what.utils.proj.proj_lp
     9
    10'''
    11
    12from what.utils.logger import get_logger
    13from what.utils.resize import bilinear_resize
    14from what.utils.proj import proj_lp